c ############################################################
c            Satellite Data Simulation Unit
c                -  The Main Program -
c
c  This program is the driver of the whole simulator unit.
c  See README files in this directory and sub-directories as
c  well as comments provided in the source codes for specific
c  instructions.
c ------------------------------------------------------------

      Program RTSIM
      Implicit none
C
C - Common variables are declared and their dimensions are defined.
C
      Include 'MAINparameters.inc'
c
      integer ifile
c
c - Sensor parameters and running options are defined.
c
      Call param_set ( freq,freq_radar,wavel,
     &                 inc_angle_mwr,inc_angle_rdr,
     &                 znth_slr,znth_obs,azmth,
     &                 background,slant_path,microw,radar,visIR,lut )
c
c - The list of input files is provided.
c
      Call def_file_list ( CRM_file_list )
c
c - Simulation is performed consecutively for each model input.
c
      Do 401 ifile = 1, nmodel
C
C - Input geophysical parameters are read in.
C
      Call rd_CRM ( press_lev, temp_lev, tskin, ics, 
     &             rainrate_sfc, wind_lev, 
     &             hgt_lev, relhum_avg, cloud_water_avg, rain_avg, 
     &             cloud_ice_avg, snow_avg, graupel_avg, hail_avg, 
     &             ngridx, ngridy, nlyr, deltax, deltay, 
     &             wind_sfc, soilH2O, CRM_file_list(ifile) )
c
c - Water vapor pressure is estimated from relative humidity.
c   (this subroutine is found in "./microw/")
c
      call vapor_pressure(ngridx, ngridy, nlyr, temp_lev, 
     &       press_lev, relhum_avg, avg_pressure, avg_H2Opressure)
c
c ##############################################################
C      --- MICROWAVE BRIGHTNESS TEMPERATURE SIMULATION ---    
c        Subroutines called here are found in "./microw/"
c ##############################################################

      If ( microw ) then
c
      umu = cos(inc_angle_mwr*3.141593/180.)
c
c - Microwave radiative transfer solver
c
      Call SIMmicro ( lut, slant_path, background, freq, umu, 
     &                press_lev, temp_lev, tskin, wind_sfc, 
     &                soilH2O, wind_lev, hgt_lev, relhum_avg, 
     &                avg_pressure, avg_H2Opressure, 
     &                cloud_water_avg, rain_avg, cloud_ice_avg, 
     &                snow_avg, graupel_avg, hail_avg, ics,
     &                ngridx, ngridy, nlyr, deltax, deltay, Tb_out )
c
c - Simulated brightness temperature is written out.
c
      Call out_micro ( Tb_out, ngridx, ngridy, nlyr, deltax, deltay,
     &                 freq, inc_angle_mwr, CRM_file_list(ifile) )
c
      Endif

c ##############################################################
c                --- RADAR ECHO SIMULATION ---
c       Subroutines called here are found in "./radar/"
c ##############################################################

      If ( radar ) then
c
      umu = cos(inc_angle_rdr*3.141593/180.)
c
c - Radar echo simulator
c
      Call SIMradar ( lut, freq_radar, umu, press_lev, temp_lev, 
     &                wind_lev, hgt_lev, relhum_avg, 
     &                avg_pressure, avg_H2Opressure, 
     &                cloud_water_avg, rain_avg, cloud_ice_avg, 
     &                snow_avg, graupel_avg, hail_avg, ics,
     &                ngridx, ngridy, nlyr, deltax, deltay, 
     &                dBZ_out, PIA_out )
c
c - Simulated radar dBZ and PIA are written out.
c
      Call out_radar ( dBZ_out, PIA_out, ngridx, ngridy, nlyr, 
     &                 deltax, deltay, freq_radar, inc_angle_rdr, 
     &                 hgt_lev, CRM_file_list(ifile) )
c
      Endif

c ##############################################################
c       --- VISIBLE AND INFRARED RADIANCE SIMULATION ---
c          Subroutines called here are found in "./vis_IR/"
c ##############################################################

      If ( visIR ) then
c
c - Visible/IR radative transfer solver
c
      Call SIMvisir(ngridx, ngridy, nlyr, wavel, znth_slr, znth_obs,
     &            azmth, hgt_lev, press_lev, temp_lev, relhum_avg,
     &            cloud_water_avg, rain_avg, cloud_ice_avg, snow_avg,
     &            graupel_avg, hail_avg, background, I_visIR )
c
c - Simulated visible/IR radiance is written out.
c
      Call out_visIR ( I_visIR, ngridx, ngridy, nlyr, deltax, deltay, 
     &                 wavel, znth_slr, znth_obs, azmth,
     &                 CRM_file_list(ifile) )
c
      Endif

c
 401  Continue
c
      stop
      end        
