      Subroutine convolv_microw ( filename, crosst_x,
     &                            fov_ct_microw, fov_dt_microw )
      Implicit NONE
c     
      Include 'BMCVparameters.inc'
c
c Inputs:
c  - file name
c     filename
c  - running options
c     crosst_x
c  - FOV sizes
c     fov_ct_microw, fov_dt_microw
c Outputs:
c  (NONE)
c
c The output file will have the same name as the original
c except that the extention ".bin" is replaced by ".fov.bin".
c Note that spatial sampling (or grid dimension and interval)
c remains unchanged.
c
      Real *4 radinp(mxgridx,mxgridy),radout
      Real *4 deltax, deltay
      Real *4 FWHMx, FWHMy
      Character*(*) filename
      Character*100 pathandfile
      Integer ngridx, ngridy, nlyr, nxsub, nysub, nchar
      Integer nx, ny, nz, nf, np, i, j, k, m, l
      Integer length_char
c
      write(*,*) ' --- Microwave FOV convolution --- '
c
      nchar = length_char ( filename )
      nchar = nchar - 8    !! to eliminate '.profile' at the end.
c
c Data dimensions in ascii format
c
      pathandfile = outputdir//filename(1:nchar)//'.mwr.info'
      open(unit= 15, file = pathandfile,
     +     status = 'old', form = 'formatted')
      read(15,551) ngridx, ngridy, nlyr, deltax, deltay
  551 format(i3,' x ',i3,' (x,y) grid; ',i3,' layers; ',
     &       ' deltax = ',f6.2,' km','  deltay = ',f6.2,' km')
c
c Read in microwave brightness temperature at the original resolution
c
      pathandfile = outputdir//filename(1:nchar)//'.mwr.bin'
      open(unit= 20, file = pathandfile, access = 'direct', 
     +     recl = ngridx*ngridy*mxfreq*2*4)
c
      read(20,rec=1) ((((Tb_microw(i,j,l,m),i=1,ngridx),j=1,ngridy),
     &                   m=0,1),l=1,mxfreq)
c
      Do 10 nf = 1 , mxfreq
         If ( crosst_x ) then
            FWHMx = fov_ct_microw(nf)
            FWHMy = fov_dt_microw(nf)
         Else
            FWHMx = fov_dt_microw(nf)
            FWHMy = fov_ct_microw(nf)
         Endif
         nxsub = nint(FWHMx / deltax)
         nysub = nint(FWHMy / deltay)
         Do 10 np = 0 , 1
            Do 20 nx = 1 , ngridx
               Do 20 ny = 1 , ngridy
                  radinp(nx,ny) = Tb_microw(nx,ny,nf,np)
 20         Continue
            Do 30 nx = 1 , ngridx
               Do 30 ny = 1 , ngridy
                  Call fov(nx,ny,ngridx,ngridy,nxsub,nysub,radinp,
     &                     mxgridx,mxgridy,
     &                     deltax,deltay,FWHMx,FWHMy,radout)
                  Tb_microw(nx,ny,nf,np) = radout
 30         Continue
 10   Continue
c
c Write out microwave brightness temperature at the FOV resolution
c
      pathandfile = outputdir//filename(1:nchar)//'.mwr.fov.bin'
      open(unit= 30, file = pathandfile, access = 'direct', 
     +     recl = ngridx*ngridy*mxfreq*2*4)
c
      write(30,rec=1) ((((Tb_microw(i,j,l,m),i=1,ngridx),j=1,ngridy),
     &                    m=0,1),l=1,mxfreq)
c
      Close (15)
      Close (20)
      Close (30)
c
      Return
      End
c
c --------------------------------------------------------------------
c
      Subroutine convolv_radar ( filename, crosst_x,
     &                           fov_ct_radar, fov_dt_radar )
      Implicit NONE
c     
      Include 'BMCVparameters.inc'
c
c Inputs:
c  - file name
c     filename
c  - running options
c     crosst_x
c  - FOV sizes
c     fov_ct_radar, fov_dt_radar
c Outputs:
c  (NONE)
c
c The output file will have the same name as the original
c except that the extention ".bin" is replaced by ".fov.bin".
c Note that spatial sampling (or grid dimension and interval)
c remains unchanged.
c
      Real *4 radinp(mxgridx,mxgridy),radout
      Real *4 deltax, deltay
      Real *4 FWHMx, FWHMy
      Character*(*) filename
      Character*100 pathandfile
      Integer ngridx, ngridy, nlyr, nxsub, nysub, nchar
      Integer nx, ny, nz, nf, np, i, j, k, m, l
      Integer length_char
c
      write(*,*) ' --- Radar FOV convolution --- '
c
      nchar = length_char ( filename )
      nchar = nchar - 8    !! to eliminate '.profile' at the end.
c
c Data dimensions in ascii format
c
      pathandfile = outputdir//filename(1:nchar)//'.rdr.info'
      open(unit= 16, file = pathandfile,
     +     status = 'old', form = 'formatted')
      read(16,551) ngridx, ngridy, nlyr, deltax, deltay
  551 format(i3,' x ',i3,' (x,y) grid; ',i3,' layers; ',
     &       ' deltax = ',f6.2,' km','  deltay = ',f6.2,' km')
c
c Read in radar reflectivity and PIA at the original resolution
c
      pathandfile = outputdir//filename(1:nchar)//'.rdr.bin'
      open(unit= 21, file = pathandfile, access = 'direct', 
     +     recl = (nlyr+1)*ngridx*ngridy*mxfreq_radar*4 )
c
      read(21,rec=1)((((dBZ_radar(i,j,k,nf),i=1,ngridx),j=1,ngridy),
     &                      k=1,nlyr),
     &                ((PIA_radar(i,j,nf),i=1,ngridx),j=1,ngridy),
     &                      nf=1,mxfreq_radar)
c
      Do 40 nf = 1 , mxfreq_radar
         If ( crosst_x ) then
            FWHMx = fov_ct_radar(nf)
            FWHMy = fov_dt_radar(nf)
         Else
            FWHMx = fov_dt_radar(nf)
            FWHMy = fov_ct_radar(nf)
         Endif
         nxsub = nint(FWHMx / deltax)
         nysub = nint(FWHMy / deltay)
c
c Reflectivity
c
         Do 45 nz = 1 , nlyr
            Do 50 nx = 1 , ngridx
               Do 50 ny = 1 , ngridy
                  radinp(nx,ny) = 10.**(dBZ_radar(nx,ny,nz,nf)*.1)
 50         Continue
            Do 55 nx = 1 , ngridx
               Do 55 ny = 1 , ngridy
                  Call fov(nx,ny,ngridx,ngridy,nxsub,nysub,radinp,
     &                     mxgridx,mxgridy,
     &                     deltax,deltay,FWHMx,FWHMy,radout)
                  If (radout.gt.0.)
     &            dBZ_radar(nx,ny,nz,nf) = 10.*log10(radout)
                  If (radout.le.0.)
     &            dBZ_radar(nx,ny,nz,nf) = -999.
 55         Continue
 45      Continue
C
c Path-integrated Attenuation
c
         Do 60 nx = 1 , ngridx
            Do 60 ny = 1 , ngridy
               radinp(nx,ny) = 10.**(-.1*PIA_radar(nx,ny,nf))
 60      Continue
         Do 65 nx = 1 , ngridx
            Do 65 ny = 1 , ngridy
               Call fov(nx,ny,ngridx,ngridy,nxsub,nysub,radinp,
     &                  mxgridx,mxgridy,
     &                  deltax,deltay,FWHMx,FWHMy,radout)
               If (radout.gt.0.)
     &         PIA_radar(nx,ny,nf) = - 10.*log10(radout)
               If (radout.le.0.)
     &         PIA_radar(nx,ny,nf) = -999.
 65         Continue
 40   Continue
c
c Write out radar reflectivity and PIA at the FOV resolution
c
      pathandfile = outputdir//filename(1:nchar)//'.rdr.fov.bin'
      open(unit= 31, file = pathandfile, access = 'direct', 
     +     recl = (nlyr+1)*ngridx*ngridy*mxfreq_radar*4 )
c
      write(31,rec=1)((((dBZ_radar(i,j,k,nf),i=1,ngridx),j=1,ngridy),
     &                      k=1,nlyr),
     &                 ((PIA_radar(i,j,nf),i=1,ngridx),j=1,ngridy),
     &                      nf=1,mxfreq_radar)
c
      Close (16)
      Close (21)
      Close (31)
c     
      Return
      End
c
c --------------------------------------------------------------------
c
      Subroutine convolv_visIR ( filename, crosst_x, tbform,
     &                           wavel, fov_ct_visir, fov_dt_visir )
      Implicit NONE
c     
      Include 'BMCVparameters.inc'
c
c Inputs:
c  - file name
c     filename
c  - running options
c     crosst_x
c  - channel info
c     tbform, wavel
c  - FOV sizes
c     fov_ct_visir, fov_dt_visir
c Outputs:
c  (NONE)
c
c The output file will have the same name as the original
c except that the extention ".bin" is replaced by ".fov.bin".
c Note that spatial sampling (or grid dimension and interval)
c remains unchanged.
c
      Real *4 radinp(mxgridx,mxgridy),radout
      Real *4 deltax, deltay
      Real *4 FWHMx, FWHMy
      Real *4 TBB,PLNK
      Character*(*) filename
      Character*100 pathandfile
      Integer ngridx, ngridy, nlyr, nxsub, nysub, nchar
      Integer nx, ny, nz, np, i, j, k, m, l, nw
      Integer length_char
c
      write(*,*) ' --- vis/IR FOV convolution --- '
c
      nchar = length_char ( filename )
      nchar = nchar - 8    !! to eliminate '.profile' at the end.
c
c Data dimensions in ascii format
c
      pathandfile = outputdir//filename(1:nchar)//'.vir.info'
      open(unit= 17, file = pathandfile,
     +     status = 'old', form = 'formatted')
      read(17,551) ngridx, ngridy, nlyr, deltax, deltay
  551 format(i3,' x ',i3,' (x,y) grid; ',i3,' layers; ',
     &       ' deltax = ',f6.2,' km','  deltay = ',f6.2,' km')
c
c Read in vis/IR radiance at the original resolution
c
      pathandfile = outputdir//filename(1:nchar)//'.vir.bin'
      open(unit= 22, file = pathandfile, access = 'direct', 
     +     recl = ngridx*ngridy*mxwavel*4)
c
      read(22,rec=1) (((I_visir(i,j,nw),i=1,ngridx),
     &                    j=1,ngridy),nw=1,mxwavel)
c
      Do 70 nw = 1 , mxwavel
         If ( crosst_x ) then
            FWHMx = fov_ct_visir
            FWHMy = fov_dt_visir
         Else
            FWHMx = fov_dt_visir
            FWHMy = fov_ct_visir
         Endif
         nxsub = nint(FWHMx / deltax)
         nysub = nint(FWHMy / deltay)
         Do 80 nx = 1 , ngridx
            Do 80 ny = 1 , ngridy
               If ( tbform(nw) ) then
                  radinp(nx,ny) = PLNK(wavel(nw),I_visir(nx,ny,nw))
               else
                  radinp(nx,ny) = I_visir(nx,ny,nw)
               Endif
 80      Continue
         Do 90 nx = 1 , ngridx
            Do 90 ny = 1 , ngridy
               Call fov(nx,ny,ngridx,ngridy,nxsub,nysub,radinp,
     &                  mxgridx,mxgridy,
     &                  deltax,deltay,FWHMx,FWHMy,radout)
               If ( tbform(nw) ) then
                  I_visir(nx,ny,nw) = TBB(wavel(nw),radout)
               Else
                  I_visir(nx,ny,nw) = radout
               Endif
 90      Continue
 70   Continue
c
c Write out visible/IR radiance at the FOV resolution
c
      pathandfile = outputdir//filename(1:nchar)//'.vir.fov.bin'
      open(unit= 32, file = pathandfile, access = 'direct', 
     +     recl = ngridx*ngridy*mxwavel*4)
c
      write(32,rec=1) (((I_visir(i,j,nw),i=1,ngridx),
     &                    j=1,ngridy),nw=1,mxwavel)
c
      Close (17)
      Close (22)
      Close (32)
c
      Return
      End
C ######################################################################
      Subroutine fov(nx,ny,ngridx,ngridy,nxsub,nysub,radinp,
     &               mxgridx,mxgridy,
     &               deltax,deltay,FWHMx,FWHMy,radout)
      Implicit none
c
c inputs
c
      Integer nx,ny,nxsub,nysub,ngridx,ngridy,mxgridx,mxgridy
      Real *4 radinp(mxgridx,mxgridy)
      Real *4 deltax,deltay,FWHMx,FWHMy
c
c locals
c
      Integer nxbegin,nxend,nybegin,nyend,i,j
      Real *4 normalize,dx,dy,beamptrn
c
c outputs
c
      Real *4 radout
c
c begin
c
      nxbegin = max(1,nx-nxsub)
      nybegin = max(1,ny-nysub)
      nxend   = min(ngridx,nx+nxsub)
      nyend   = min(ngridy,ny+nysub)
      radout  = 0.
      normalize = 0.
c
      Do 10 i = nxbegin, nxend
         Do 10 j = nybegin, nyend
            dx = (nx-i) * deltax
            dy = (ny-j) * deltay
            radout    = radout    + deltax * deltay *
     &                      beamptrn(dx,dy,FWHMx,FWHMy) * radinp(i,j)
            normalize = normalize + deltax * deltay *
     &                      beamptrn(dx,dy,FWHMx,FWHMy)
 10   Continue
      radout = radout / normalize
C     
      Return
      End
c --------------------------------------------------------
      Real *4 Function beamptrn(x,y,FWHMx,FWHMy)
      Implicit NONE
      Real *4 x, y, FWHMx, FWHMy
c
c
C Gaussian beam pattern
c
      beamptrn = exp( - ((x/FWHMx)**2 + (y/FWHMy)**2)*4*log(2.))
c
      Return
      End
c ########################################################
      FUNCTION TBB(WL,BB)
C CALCULAION Brightness temperature
C--- History
C 1994.1.11 CCS
C--- Input
C WL     R     Wavelength in micron
C BB     R     Radiance (Watt/m2/str/micron)
C--- Output
C TBB    R     Brightness temperature (K)
C
      TBB=1.438786E4/WL/LOG(1.1911E8/WL**5/BB+1)
      RETURN
      END
c --------------------------------------------------------      
      FUNCTION PLNK(WL,TBB)
C
      PLNK = 1.1911e8/WL**5/(EXP(1.438786e4/TBB/WL)-1)
C
      RETURN
      END
