      Subroutine mie_lut(Tavg,q_hyd,
     &                   kext_lut,salb_lut,pbck_lut,
     &                   pts_temp, pts_hydro,
     &                   npts_temp, npts_hydro,
     &                   mxpts_temp, mxpts_hydro,
     &                   kext,salb,pbck)
      Implicit NONE
c
c This subroutine find the extinction/scattering coefficients for
c given T and hydrometeor content using the Mie LUTs.
c
c Inputs:
c  - temperature and hydrometeor
c     Tavg, q_hyd
c  - LUT values
c     kext_lut, salb_lut, pbck_lut
c  - LUT dimensions and independent variable vector
c     mxpts_hydro, npts_hydro, mxpts_temp, npst_temp
c
c Outputs:
c  - radiative properties
c     kext, salb, pbck
C
      Integer mxpts_temp,mxpts_hydro
c
c input & output
c 
      real *4 freqcy , Tavg, D0, q_hyd, kext, salb, pbck
      real *4 pts_hydro(mxpts_hydro)
      real *4 pts_temp(mxpts_temp)
      real *4 kext_lut(mxpts_temp, mxpts_hydro), 
     $     salb_lut(mxpts_temp, mxpts_hydro),
     $     pbck_lut(mxpts_temp, mxpts_hydro)
c
c local
c
      real *4 fT,fq,kext_l,kext_u,pbck_l,pbck_u,salb_l,salb_u
      Integer i,j
      Integer npts_temp,npts_hydro
c
c initialization
c
      kext = 0.
      salb = 0.
      pbck = 0.
c
c If input T and q are out of range,
c
      If (q_hyd .le. 0.)                    Return
      If (Tavg  .lt. pts_temp(1))           Return
      If (Tavg  .gt. pts_temp(npts_temp))   Return
      If (q_hyd .lt. pts_hydro(1))          Return
      If (q_hyd .gt. pts_hydro(npts_hydro)) Return
c
c interpolation
c
      Do 10 i = 2 , npts_temp
         If (Tavg .gt. pts_temp(i)) Goto 10
         fT = (pts_temp(i)-Tavg) / (pts_temp(i)-pts_temp(i-1))
c
         Do 20 j = 2 , npts_hydro
            If (q_hyd .gt. pts_hydro(j)) Goto 20
            fq = (pts_hydro(j)-q_hyd) / (pts_hydro(j)-pts_hydro(j-1))
c
            kext_l = fq*kext_lut(i-1,j-1) + (1.-fq)*kext_lut(i-1,j)
            kext_u = fq*kext_lut(i  ,j-1) + (1.-fq)*kext_lut(i  ,j)
            kext   = fT*kext_l            + (1.-fT)*kext_u
c
            salb_l = fq*salb_lut(i-1,j-1) + (1.-fq)*salb_lut(i-1,j)
            salb_u = fq*salb_lut(i  ,j-1) + (1.-fq)*salb_lut(i  ,j)
            salb   = fT*salb_l            + (1.-fT)*salb_u
c
            pbck_l = fq*pbck_lut(i-1,j-1) + (1.-fq)*pbck_lut(i-1,j)
            pbck_u = fq*pbck_lut(i  ,j-1) + (1.-fq)*pbck_lut(i  ,j)
            pbck   = fT*pbck_l            + (1.-fT)*pbck_u
c
            Return
 20      Continue
 10   Continue
c
      If ( npts_temp.eq.1 ) then
c     
         Do 30 j = 2 , npts_hydro
            If (q_hyd .gt. pts_hydro(j)) Goto 30
            fq = (pts_hydro(j)-q_hyd) / (pts_hydro(j)-pts_hydro(j-1))
c
            kext = fq*kext_lut(1,j-1) + (1.-fq)*kext_lut(1,j)
            salb = fq*salb_lut(1,j-1) + (1.-fq)*salb_lut(1,j)
            pbck = fq*pbck_lut(1,j-1) + (1.-fq)*pbck_lut(1,j)
c
            Return
 30      Continue
c
      Endif
c
      Return
      End
