      Subroutine out_radar( dBZ_out, PIA_out, ngridx, ngridy, nlyr, 
     &                      deltax, deltay, freq_radar, inc_angle_rdr,
     &                      hgt_lev, filename )
      Implicit NONE
c
c This subroutine writes out radar Z and PIA.
c
c Inputs:
c  - Sensor and model parameters
c     freq_radar, inc_angle_rdr, hgt_lev
c  - Model spatial dimensions
c     ngridx, ngridy, nlyr, deltax, deltay
c  - I/O
c     filename
c  - Simulated result
c     dBZ_out, PIA_out
c
c Output:
c  - (NONE)
c
      Include '../MAINparameters.inc'
c
      Integer i,j,k,l,nchar,length_char
      character*(*) filename
      character*90 pathandfile
c
      nchar = length_char ( filename )
      nchar = nchar - 8    !! to eliminate '.profile' at the end.
c
c Data dimensions in ascii format
c
      pathandfile = outputdir//filename(1:nchar)//'.rdr.info'
      open(unit= 16, file = pathandfile, 
     +     status = 'unknown', form = 'formatted')
c
      write(16,551) ngridx, ngridy, nlyr, deltax, deltay
      write(16,*) 'viewing angle:',inc_angle_rdr
      write(16,*) mxfreq_radar,'frequencies at', freq_radar,' GHz.'
      write(16,*) 'Layer altitudes [km]:'
      Do k = 1, nlyr
         write(16,*) .5*(hgt_lev(k)+hgt_lev(k-1))
      End do
c
c Computed radar echoes in binary format
c
      pathandfile = outputdir//filename(1:nchar)//'.rdr.bin'
      open(unit= 21, file = pathandfile, access='direct',
     +        recl=(nlyr+1)*ngridx*ngridy*mxfreq_radar*4)
c
      write(21,rec=1) ((((dBZ_out(l,i,j,k),i=1,ngridx),j=1,ngridy)
     &                                                ,k=1,nlyr),
     &                  ((PIA_out(l,i,j)  ,i=1,ngridx),j=1,ngridy)
     &                                          ,l=1,mxfreq_radar)
c
  551 format(i3,' x ',i3,' (x,y) grid; ',i3,' layers; ',
     &       ' deltax = ',f6.2,' km','  deltay = ',f6.2,' km')
c
      Close (16)
      Close (21)
c
      Return
      End

